@@ -28,6 +28,7 @@ const Gtk = imports.gi.Gtk;
 const Pango = imports.gi.Pango;
 
 const InstructionRow = imports.instructionRow;
+const Transit = imports.transit;
 const TransitRouteLabel = imports.transitRouteLabel;
 const TransitStopRow = imports.transitStopRow;
 const Utils = imports.utils;
@@ -57,33 +58,14 @@ var TransitLegRow = GObject.registerClass({
         this._mapView = params.mapView;
         delete params.mapView;
 
-        this._print = params.print;
-        delete params.print;
-
         super._init(params);
 
         this._modeImage.icon_name = this._leg.iconName;
-        if (this._start) {
-            if (this._leg.from) {
-                /* Translators: this is a format string indicating instructions
-                 * starting a journey at the address given as the parameter
-                 */
-                this._fromLabel.label = _("Start at %s").format(this._leg.from);
-            } else {
-                /* Translators: this indicates starting a journey at a location
-                 * with no set name (such as when the user started routing from
-                 * an arbitrary point on the map)
-                 */
-                this._fromLabel.label = _("Start");
-            }
-        } else {
-            this._fromLabel.label = this._leg.from;
-        }
+        this._fromLabel.label = Transit.getFromLabel(this._leg, this._start);
 
         if (this._leg.transit) {
             let routeLabel = new TransitRouteLabel.TransitRouteLabel({
                                     leg: this._leg,
-                                    print: this._print
                                  });
 
             this._routeGrid.add(routeLabel);
@@ -109,31 +91,20 @@ var TransitLegRow = GObject.registerClass({
 
         if (!this._leg.transit || this._leg.headsign) {
             /* Restrict headsign label to 20 characters to avoid horizontally
-             * overflowing the sidebar, make an exception for printing where
-             * we allow it use the available space.
+             * overflowing the sidebar.
              */
-            let maxWidthChars = this._print ? -1 : 20;
             let headsignLabel = new Gtk.Label({ visible: true,
                                                 can_focus: false,
                                                 use_markup: true,
                                                 hexpand: true,
                                                 margin_start: 3,
-                                                max_width_chars: maxWidthChars,
+                                                max_width_chars: 20,
                                                 ellipsize: Pango.EllipsizeMode.END,
                                                 halign: Gtk.Align.START });
-            if (this._leg.transit && this._leg.headsign) {
-                let label = GLib.markup_escape_text(this._leg.headsign, -1);
-                headsignLabel.label = '<span size="small">%s</span>'.format(label);
-            } else if (!this._leg.transit) {
-                let label =
-                    /* Translators: this is a format string indicating walking a certain
-                     * distance, with the distance expression being the %s placeholder
-                     */
-                    _("Walk %s").format(Utils.prettyDistance(this._leg.distance));
-                headsignLabel.label =
-                    '<span size="small">%s</span>'.format(label);
-            }
+            let label =
+                GLib.markup_escape_text(Transit.getHeadsignLabel(this._leg), -1);
 
+            headsignLabel.label = '<span size="small">%s</span>'.format(label);
             headsignLabel.get_style_context().add_class('dim-label');
             this._routeGrid.add(headsignLabel);
         }
@@ -163,13 +134,6 @@ var TransitLegRow = GObject.registerClass({
         });
 
         this._isExpanded = false;
-
-        // hide expand/collaps row in printing mode
-        this._footerStack.visible = !this._print;
-
-        // allow more space for the departure label when printing
-        if (this._print)
-            this._fromLabel.max_width_chars = -1;
     }
 
     // Handle events received on the EventBox for expanding when clicking
